MqttServer

Struct MqttServer 

pub struct MqttServer<LoginH, SubH> { /* private fields */ }
A complete MQTT Server

This server should be seen as a toolkit to integrate with your application.

To use it, you first need to get a new instance of it, check out any of the serve_* methods that create a new instance. Then, you need to start listening for new connections in a long lived future.

Check out the server example for a working version.

Implementations

Source

impl MqttServer<AllowAllLogins, AllowAllSubscriptions>

pub async fn serve_v3_unsecured_tcp<Addr: ToSocketAddrs>( addr: Addr, ) -> Result<Self, MqttError>

Create a new MQTT server listening on the given SocketAddr

Source

impl<LH: LoginHandler, SH: SubscriptionHandler> MqttServer<LH, SH>

pub fn with_login_handler<NLH: LoginHandler>( self, new_login_handler: NLH, ) -> MqttServer<NLH, SH>

Switch the login handler with a new one

Note

You should only call this after instantiating the server, and before listening

pub fn with_subscription_handler<NSH: SubscriptionHandler>( self, new_subscription_handler: NSH, ) -> MqttServer<LH, NSH>

Resets the subscription handler to a new one

Note

You should only call this after instantiating the server, and before listening

pub async fn accept_new_clients(&self) -> Result<(), MqttError>

Start accepting new clients connecting to the server

pub fn subscribe_to_message<Fut: Future<Output = ()>, CB: FnMut(MqttMessage) -> Fut + 'static>( &self, topic_paths: Vec<String>, callback: CB, ) -> impl Future<Output = Result<(), MqttError>> + 'static

Listen to messages sent to the given topic_paths